@@ -16,6 +16,7 @@ import re
 import time
 import inspect
 import tokenize, token, keyword
+import itertools
 try:
     import io
 except ImportError:  # Not on Python 2.4
@@ -57,6 +58,20 @@ TIMEIT_MESSAGE = """Time execution duration. Usage:
     timeit 20 fun/expression  # tests 20 passes
 """
 
+def _detect_equalbang(line) :
+    try:
+        gtoks = tokenize.tokenize(io.BytesIO(line.encode('utf-8')).readline)
+        # iteration on two successive elements, https://docs.python.org/3/library/itertools.html#itertools-recipes
+        first, second = itertools.tee(gtoks)
+        next(second, None)
+        for tok1, tok2 in zip(first, second) :
+            if tok1.type == token.OP and tok1.string == "=" and tok2.type == token.ERRORTOKEN and tok2.string == "!" :
+                return True
+        return False
+    except tokenize.TokenError:  # typically this means an unmatched parenthesis
+        return False
+
+
 def _should_not_interpret_as_magic(line):
     interpreter = sys._pyzoInterpreter
     
@@ -70,24 +85,24 @@ def _should_not_interpret_as_magic(line):
     
     # ignore garbage and indentation at the beginning
     pos = 0
-    while pos < len(ltok) and ltok[pos][0] in [59, token.INDENT, tokenize.ENCODING]:
+    while pos < len(ltok) and ltok[pos].type in [59, token.INDENT, tokenize.ENCODING]:
         # 59 is BACKQUOTE but there is no token.BACKQUOTE...
         pos = pos + 1
     # when line is only garbage or does not begin with a name
-    if pos >= len(ltok) or ltok[pos][0] != token.NAME:
+    if pos >= len(ltok) or ltok[pos].type != token.NAME:
         return True
-    command = ltok[pos][1]
+    command = ltok[pos].string
     if keyword.iskeyword(command):
         return True
     pos = pos + 1
     # command is alone on the line
-    if pos >= len(ltok) or ltok[pos][0] in [token.ENDMARKER, tokenize.COMMENT]:
+    if pos >= len(ltok) or ltok[pos].type in [token.ENDMARKER, tokenize.COMMENT]:
         if command in interpreter.locals:
             return True
         if interpreter.globals and command in interpreter.globals:
             return True
     else: # command is not alone ; next token should not be an operator (this includes parentheses)
-        if ltok[pos][0] == token.OP and not line.endswith('?'):
+        if ltok[pos].type == token.OP and not line.endswith('?'):
             return True
     
     return False
@@ -149,6 +164,9 @@ class Magician:
         interpreter = sys._pyzoInterpreter
         command = line.rstrip()
         
+        if interpreter._ipython and _detect_equalbang(line) :
+                return self.equalbang_quirk(line, command)
+        
         have_hard_chars = 'cd ', '?'
         if PYTHON_VERSION >= 3 and not command.lower().startswith(have_hard_chars):
             try:
@@ -271,6 +289,10 @@ class Magician:
         # Done (no code to execute)
         return ''
     
+    def equalbang_quirk(self, line, command) :
+        print("`=!' is not valid Python. To check for non-equality, use `!='.")
+        print("If you intend to use IPython's ! magic feature and assign its result, please write `= !'.")
+        return ''
     
     def cd(self, line, command):
         if command == 'CD' or command.startswith("CD ") and '=' not in command:
